#!/usr/bin/env python3
import sentry_sdk
from sentry_sdk.integrations.flask import FlaskIntegration
from flask import Flask
from werkzeug.middleware.proxy_fix import ProxyFix

# import stuff
from model import db

from utils import register_all_error_handlers, storage

# import views
from views import SVMView, CNNView, RootView

from config import Config

if Config.SENTRY_DSN:
    sentry_sdk.init(
        dsn=Config.SENTRY_DSN,
        integrations=[FlaskIntegration()],
        send_default_pii=True,
        release=Config.RELEASE_ID,
        environment=Config.RELEASEMODE
    )

# create flask app
app = Flask(__name__)
app.wsgi_app = ProxyFix(app.wsgi_app, x_proto=1)

# load config
app.config.from_object(Config)

# initialize stuff
db.init_app(app)
storage.init_app(app)


@app.before_first_request
def create_db():
    db.create_all()


# register error handlers
register_all_error_handlers(app)

# register views
for view in [SVMView, CNNView, RootView]:
    view.register(app, trailing_slash=False, route_prefix='/model')

# start debuggig if needed
if __name__ == "__main__":
    app.run(debug=True)
else:
    import logging

    gunicorn_logger = logging.getLogger('gunicorn.error')
    app.logger.handlers = gunicorn_logger.handlers
    app.logger.setLevel(gunicorn_logger.level)
